<!DOCTYPE html>
<html lang="en">
<head>
	<meta charset="UTF-8">
	<title>Inventory Management System</title>
	<link rel="stylesheet" href="styles.css" type="text/css">

<script>
function refreshPage()
{
	window.location.reload();
}

function resetForm()
{
	document.getElementById("product").value="000000";
	document.getElementById("update").value="0";
	document.getElementById("radioAdd").checked = false;
	document.getElementById("radioRemove").checked = false;
}

function submitRequest()
{
	/* retreive the values from the form */
	const productValue = document.getElementById("product").value;
	const updateValue = document.getElementById("update").value;
	/* get the values for all radio buttons */
	const radioValues = document.getElementsByName("operation");
	/* retreive only the value for the checked button */
	radioValues.forEach((operation) => {
		if (operation.checked)
		{
			operationValue = operation.value;
		}
	});

	/* check that the values are acceptable */
	if (productValue.length == 6)
	{
		/* productValue = 439 plus 3 digits */
		const regularExpression = /439\d{3}/;
		const reTest = regularExpression.test(productValue);
		if (!reTest)
		{
			document.getElementById("message").innerHTML = "<p class=\"warning\">Incorrect product</p>";
			resetForm();
			return false;
		}
	}
	else
	{
		document.getElementById("message").innerHTML = "<p class=\"warning\">Incorrect product</p>";
		resetForm();
		return false;
	}

	/* updateValue = integer between 1 and 99 */
	if ((updateValue < 1) || (updateValue > 99))
	{
		document.getElementById("message").innerHTML = "<p class=\"warning\">Incorrect value</p>";
		resetForm();
		return false;
	}

	/* check that the value will not drop to zero or lower */
	const currentValue = Number(document.getElementById("qty_"+productValue).innerHTML);
	if ((currentValue - updateValue) <= 0)
	{
		document.getElementById("message").innerHTML = "<p class=\"warning\">You cannot remove more products than the current quantity.</p>";
		resetForm();
		return false;
	}

	/* operationValue = only 'add' and 'remove' */
	/* warning: if no option is checked the form submission is not processed */
	/* no error message will be displayed */
	if ((operationValue !== "add") && (operationValue !== "remove"))
	{
		document.getElementById("message").innerHTML = "<p class=\"warning\">Incorrect operation</p>";
		resetForm();
		return false;
	}

	const parameters = "product="+productValue+"&update="+updateValue+"&operation="+operationValue;

	/* create and send a HTTP request via AJAX */
	var request = new XMLHttpRequest();
	request.open("POST", "update.php", true);
	request.setRequestHeader("Content-type", "application/x-www-form-urlencoded");
	request.send(parameters);

	request.onreadystatechange = function()
	{
		if (this.readyState === 4 && this.status === 200)
		{
			/* display the feedback message */
			document.getElementById("message").innerHTML = this.responseText;

			/* update the table quantity */
			if (operationValue === "add")
			{
				document.getElementById("qty_"+productValue).innerHTML = currentValue + Number(updateValue);
			}
			else
			{
				document.getElementById("qty_"+productValue).innerHTML = currentValue - Number(updateValue);
			}
		}
	};

	resetForm();
}
</script>
</head>
<body>

<h1>Inventory Management System</h1>

<?php
$query = 'SELECT * FROM inventory';

/* opening the sqlite database file */
$dbfile = new PDO('sqlite:../inventory.db3');

/* run the query */
$query = $dbfile->query($query);
$results = $query->fetchAll();
$dbfile = null;

/* display the inventory table */
print("<table>\n");
print("<colgroup>\n");
print("<col span=\"1\" style=\"width: 15%;\">\n");
print("<col span=\"1\" style=\"width: 70%;\">\n");
print("<col span=\"1\" style=\"width: 15%;\">\n");
print("</colgroup>\n");
print("<tr><th>Reference</th><th>Name</th><th>Quantity</th></tr>\n");

foreach ($results as $value)
{
	print("<tr><td class=\"center\">".$value['ProductReference']."</td><td>".$value['ProductName']."</td><td class=\"center\" id=\"qty_".$value['ProductReference']."\">".$value['Quantity']."</td></tr>\n");
}

print("</table>\n");

print ("<div class=\"container\">\n");
print ("<div id=\"left\">\n");

print ("<fieldset>\n");
/* product selection form */
print ("<div id=\"name\">\n");
print ("<label>Product Name</label>\n");
print ("<select id=\"product\">\n");
/* display a default null option */
print ("<option value=\"000000\">Select a product...</option>\n");

/* list all product references in the database */
foreach ($results as $value)
{
	print ("<option value=\"$value[ProductReference]\">$value[ProductName]</option>\n");
}
print ("</select>\n");
print ("</div>\n");

/* update operation form */
print ("<div id=\"quantity\">\n");
print ("<label>Quantity Update</label>\n");
print ("<input type=\"number\" id=\"update\" value=\"0\" min=\"1\" max=\"99\"><br>\n");
print ("<input type=\"radio\" id=\"radioAdd\" name=\"operation\" value=\"add\">Add<br>\n");
print ("<input type=\"radio\" id=\"radioRemove\" name=\"operation\" value=\"remove\">Remove<br>\n");
print ("</div>\n");

print ("<button type=\"button\" id=\"refresh\" onclick=\"refreshPage()\">Refresh</button>\n");
print ("<button type=\"button\" id=\"updateButton\" onclick=\"submitRequest()\">Update</button>\n");

print ("</fieldset>\n</div>\n");
print ("<div id=\"right\">\n");
print ("<div id=\"message\">\n");
print ("</div>\n</div>\n</div>\n");

?>
</body>
</html>
